"""
MSAMDD – Exact multiple-sequence alignment with Synchronized DDs.

Exports
-------
msa_cnv : callable
    Alignment with convex gap costs (wrapper around the compiled _optmsa_cnv extension).
msa_aff : callable
    Alignment with affine gap costs (wrapper around the compiled _optmsa_aff extension).

__version__ : str
    Package version taken from installed metadata, or "0.0.0.dev0" when run from source.
"""

# Public API – wrappers generated by the C++ extensions -----------------------
from ._optmsa_cnv import run_convex as msa_cnv  # noqa: F401
from ._optmsa_aff import run_affine as msa_aff  # noqa: F401

__all__ = ["msa_cnv", "msa_aff", "__version__"]

# -----------------------------------------------------------------------------  
# Package version, fetched from metadata at install time.
# Falls back to a dev string when the package is executed from source checkout.
# -----------------------------------------------------------------------------
from importlib import metadata as _metadata

try:
    __version__: str = _metadata.version(__name__)
except _metadata.PackageNotFoundError:  # pragma: no cover
    __version__ = "0.0.0.dev0"
